Theming - Semantic

Brand
Link Link
Dropdown
Action
Another Action
Something else here
Separated Link
One more separated link
Link
Brand
Link
Link
Dropdown
Action
Another Action
Something else here
Separated Link
One more separated link
Link
Link
Link
Dropdown
Action
Another Action
Something else here
Separated Link
One more separated link
Dropdown Left
Link Link
Header
Sub Menu
Link
Sub Sub Menu
Link Link
Link
Link
Link
Link
Link Link
Link
Link Link
Link
Link
Right Text